package de.intevation.gnv.state;

import java.io.Serializable;

import java.util.Collection;
import java.util.List;

/**
 * This is the interface description of an <code>OutputMode</code>. The
 * methods defined here retrieve some basic information for an output. An output
 * can be chart, histogram, statistic, csv, odv and so on.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public interface OutputMode extends Serializable {

    /**
     * Retrieve the name of this output mode.
     *
     * @return the name of this output mode.
     */
    public String getName();

    /**
     * Retrieve the description of an output.
     *
     * @return the description.
     */
    public String getDescription();

    /**
     * Retrieve the mimetype used for the output.
     *
     * @return the mimetype.
     */
    public String getMimeType();

    /**
     * Retrieve a list of optional InputValue objects the user is able to
     * adjust.
     *
     * @return optional input parameters.
     */
    public Collection<InputValue> getInputParameters();

    /**
     * Retrieve a list of export modes this output can be exported to.
     *
     * @return some export modes.
     */
    public List<ExportMode> getExportModes();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :